import {Component, ElementRef, OnInit, ViewChild} from '@angular/core';
import {ActivatedRoute} from '@angular/router';
import {Api} from '../../service/api';
import {AlertController} from '@ionic/angular';
import {DatePipe} from '@angular/common';
import { IonInfiniteScroll } from '@ionic/angular';

@Component({
    selector: 'v-env-alarm-detail',
    templateUrl: './env-alarm-detail.page.html',
    styleUrls: ['./env-alarm-detail.page.scss'],
})
export class EnvAlarmDetailPage implements OnInit {

    displayArea = '';
    isTroubleDis = false;
    isAlarmDis = false;
    fieldRegionNo = '';
    fieldRegionName = '';
    fieldRegionGroup = '';

    detailInfo: any = {};
    troubleList = [];
    // detailInfoLength = 0;
    disposeState = '';
    fieldDeviceType = '';
    startTime = null;
    stopTime = null;
    curInterval = 12;
    item = {};

    displayLength = 0;

    page = 1;
    rows = 10;

    // 工作模式
    workModeSetting = {
        'workMode': '风机',
        'DeviceNo': '',
        'workModeOld': '1'
    };

    // commTmr: any;

    @ViewChild(IonInfiniteScroll) infiniteScroll: IonInfiniteScroll;
    // @ViewChild('currentItem') currentItem;

    constructor(private ac: ActivatedRoute, private api: Api,
                private alterContoller: AlertController, private datePipe: DatePipe) {
    }

    ngOnInit() {
        this.init();
        // this.commTmr = window.setInterval(() => {
        //     console.log(1);
        //     if (this.displayArea  === 'trouble') {
        //         this.showAlarmList = this.troubleList;
        //     } else {
        //         this.showAlarmList = this.alarmList;
        //     }
        //
        // }, 1000) ;
    }

    ionViewWillLeave() {
        console.log('ionViewWillLeave');
        this.page = 1;
        this.disposeState = '';
        this.fieldDeviceType = '';
        this.detailInfo = {};
        this.troubleList = [];
        this.infiniteScroll.disabled = false;
    }

    init() {
        this.page = 1;
        this.displayLength = 0;
        this.detailInfo = {};
        this.troubleList = [];
        this.ac.queryParams.subscribe((data) => {
            console.log('init');
            this.fieldRegionNo = data.no;
            this.displayArea = data.displayArea;
            this.curInterval = data.interval;

            this.setDateInterval(this.curInterval);
            this.showArea(data.displayArea);
            this.getTroubleList(true);
            this.getAlarmList(true);
        });
    }

    setDateInterval(interval) {
        this.startTime = this.datePipe.transform(this.getStartTime(interval), 'yyyy-MM');
        this.stopTime = this.datePipe.transform(new Date(), 'yyyy-MM');
    }

    showArea(displayArea) {
        this.isTroubleDis = displayArea === 'trouble' ? true : false;
        this.isAlarmDis = displayArea === 'alarm' ? true : false;
    }

    getTroubleList(isInit) {
        if (this.displayArea === 'trouble') {
            this.isTroubleDis = true;
            const req = {
                fieldRegionNo: this.fieldRegionNo,
                startTime: this.parseTime(this.startTime, 'start'),
                stopTime: this.parseTime(this.stopTime, 'stop'),
                disposeState: '',
                fieldDeviceType: ''
            };
            if (this.disposeState !== null && this.disposeState !== '' && this.disposeState !== '全部') {
                req.disposeState = this.disposeState;
            }
            if (this.fieldDeviceType !== null && this.fieldDeviceType !== '' && this.fieldDeviceType !== '全部') {
                req.fieldDeviceType = this.fieldDeviceType;
            }
            this.api.troubleLog.getByTerm(this.page, this.rows, [req, (data) => {
                if (data.trouble && data.trouble.constructor === Array) {
                    data.trouble.forEach((item) => {
                        item.data = JSON.parse(item.data);
                        item.troubleTime = this.api.formatTime('yyyy-MM-dd hh:mm:ss', new Date(item.troubleTime));
                    });
                }
                if (isInit) {
                    this.detailInfo = data;
                }
                this.appendItems(data.trouble, data.devErrTotal);
                // this.detailInfoLength = data.trouble.length;
            }]);
        }
    }

    getAlarmList(isInit) {
        if (this.displayArea === 'alarm') {
            this.isAlarmDis = true;
            const req = {
                fieldRegionNo: this.fieldRegionNo,
                startTime: this.parseTime(this.startTime, 'start'),
                stopTime: this.parseTime(this.stopTime, 'stop'),
                disposeState: '',
                fieldDeviceType: ''
            };
            if (this.disposeState !== null && this.disposeState !== '' && this.disposeState !== '全部') {
                req.disposeState = this.disposeState;
            }
            if (this.fieldDeviceType !== null && this.fieldDeviceType !== '' && this.fieldDeviceType !== '全部') {
                req.fieldDeviceType = this.fieldDeviceType;
            }
            this.api.alarm.getCowshedAlarm(this.page, this.rows, [req, (data) => {
                if (data.trouble && data.trouble.constructor === Array) {
                    data.trouble.forEach((item) => {
                        item.data = JSON.parse(item.data);
                        item.troubleTime = this.api.formatTime('yyyy-MM-dd hh:mm:ss', new Date(item.alarmTime));
                    });
                }
                if (isInit) {
                    this.detailInfo = data;
                }
                this.appendItems(data.trouble, data.alarmTotal);
                // this.detailInfoLength = data.trouble.length;
            }]);
        }
    }

    appendItems(trouble, allDataLength) {
        // await this.wait(500);
        console.log(allDataLength);
        console.log(this.troubleList.length);
        if (trouble && trouble.length > 0 ) {
            for (let i = 0; i < trouble.length; i++) {
                this.troubleList.push(trouble[i]);
                this.displayLength = this.displayLength + 1;
            }
            // this.infiniteScroll.disabled = false;
            this.page = this.page + 1;
        } else {
            // this.infiniteScroll.disabled = true;
        }
    }

    loadData(event) {
        setTimeout(() => {
            console.log('loadData Done');
            this.getTroubleList(false);
            this.getAlarmList(false);
            event.target.complete();
            // App logic to determine if all data is loaded
            // and disable the infinite scroll
            // if (data.length == 1000) {
            // event.target.disabled = true;
            // }
        }, 500);
    }

    segmentChanged(ev: any) {
        console.log('segment changed');
        this.page = 1;
        this.disposeState = '';
        this.fieldDeviceType = '';
        this.detailInfo = {};
        this.troubleList = [];
        this.infiniteScroll.disabled = false;
        if (ev.target.value === 'alarm') {
            this.displayArea = 'alarm';
            this.getAlarmList(true);
        } else {
            this.displayArea = 'trouble';
            this.getTroubleList(true);
        }
    }

    // 确认修复
    async onRecvClick(alarm) {
        console.log(alarm);

        const alert = await this.alterContoller.create({
            header: '请注意',
            message: '请确认该故障是否为真实故障?',
            mode: 'ios',
            buttons: [
                {
                    text: '取消',
                    role: 'cancel',
                    cssClass: 'secondary',
                    // cssClass: 'width: 30%',
                }, {
                    text: '是',
                    // cssClass: 'width: 40%',
                    handler: () => {
                        this.processingFailure(1, alarm);
                    }
                }, {
                    text: '不是',
                    // cssClass: 'width: 30%',
                    handler: () => {
                        this.processingFailure(0, alarm);
                    }
                }
            ]
        });

        await alert.present();
    }

    processingFailure(real, alarm) {
        const req = {
            troubleLogNo: this.displayArea === 'alarm' ? alarm.alarmLogNo : alarm.troubleLogNo,
            disposeState: 1,
            isReal: real === 1 ? 1 : 0
        };
        this.api.troubleLog.processingFailure([req, (data) => {
            if (data && data.code === 1) {
                this.api.presentMsgToast(data.message);
            } else {
                this.api.presentMsgToast(data.message);
            }
            this.refresh();
        }]);
    }

    getStartTime(interval) {
        const now = new Date;
        const year = now.getFullYear();
        const month = now.getMonth() - interval;
        const day = now.getDate();
        const time = new Date(year, month, day, 0, 0, 0);
        return time;
    }

    parseTime(time, flg) {
        const year = time.slice(0, 4);
        const month = parseInt(time.slice(5, 7), 10);
        let updateTime = 0;
        if (flg === 'start') {
            updateTime = new Date( year, month - 1, 1, 0, 0, 0).valueOf();
        } else {
            updateTime = new Date( year, month, 0, 23, 59, 59).valueOf();
        }
        return updateTime;
    }

    refresh() {
        console.log('refresh');
        this.detailInfo = {};
        this.troubleList = [];
        this.page = 1;
        this.displayLength = 0;
        this.infiniteScroll.disabled = false;
        this.getTroubleList(false);
        this.getAlarmList(false);
    }

    wait(time) {
        return new Promise(resolve => {
            setTimeout(() => {
                resolve();
            }, time);
        });
    }
}
